function [beta,gampm,gampc] = mnl_auxmix_drum(m,chy,Z,beta,b0,B0inv)
%% MCMC for multinomial logit model based on Frhwirth-Schnatter and Frhwirth (2010)
% and extended by Sylvia Kaufmann (2012) to apply the random permutation
% sampler.
%
%  data augmentation in the partila dRUM modelS 

% input parameters:

%  Z    ... predictor matrix, array size N x d
%  beta ... old draw of the regression parameter, array size d x (m+1);
%           should be equal to 0 in the baseline 
%  b0   ... prior mean, array size d x (m+1) 
%  B0   ... prior information matrix, array size d x d x (m+1) 

% output parameters:

%  beta ... new draw of the regression parameter, array size d x (m+1)

% calls following functions directly or indirectly:
%  mcmc_bin_diff_util_logit
%  mcmc_logit_diff_indic, define_normmix_diff

%% initialize
gampm=zeros(size(beta));
gampc=zeros(size(beta,1),size(beta,1),m+1);
k0=find(all(beta==0,1));

if any(beta(:,k0)~=0) 
    'Warning in function mnl_auxmix_drum: Parameter in the baseline non zero'
end; 
kindex=[1:k0-1 k0+1:m+1];

d=size(Z,2);
predlin=Z*beta;

%% sampling from the partial dRUM

for k=kindex
    
    % sample regression and scale parameters given latents
    
    cc=log(sum(exp(predlin(:,[1:k-1 k+1:end])),2));
    utildiff = mcmc_bin_diff_util_logit(predlin(:,k)-cc,chy==k);
    
    % sample omega
    Kmix=6;
    omega = mcmc_logit_diff_indic(6,utildiff,predlin(:,k)-cc);
    
    Zomega=Z./repmat(omega.^.5,1,d);
    utilomega=(utildiff+cc)./omega.^.5;
    
    BNinv=Zomega'*Zomega  + B0inv(:,:,k);
    BNcov=inv(BNinv);
    BNchol=chol(BNcov)';
    
    bN=BNcov*(Zomega'*utilomega +B0inv(:,:,k)*b0(:,k));
    
    beta(:,k)=bN+BNchol*randn(d,1);
    predlin(:,k)=Z*beta(:,k);
    gampm(:,k)=bN;
    gampc(:,:,k)=BNcov;
    
end




